==> atlassian-bamboo-plugin-git-1.9.11-sources.jar: com/atlassian/bamboo/plugins/git/UriUtils.java <==
package com.atlassian.bamboo.plugins.git;


import org.eclipse.jgit.transport.URIish;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.io.File;
import java.net.URI;
import java.net.URISyntaxException;

public class UriUtils
{
    static final String SSH_SCHEME = "ssh";
    static final String SCHEME_DELIMITER = "://";

    private UriUtils()
    {
    }

    @Nullable
    public static String extractUsername(final String repositoryUrl) throws URISyntaxException
    {
        URIish uri = new URIish(repositoryUrl);

        final String auth = uri.getUser();
        if (auth == null)
        {
            return null;
        }
        return auth;
    }


    public static boolean isSsh(@NotNull ScpAwareUri repositoryUri)
    {
        String scheme = repositoryUri.getScheme();
        return (scheme == null && repositoryUri.getAbsolutePath() == null) || scheme.equals(SSH_SCHEME);
    }

    public static boolean isSsh(@NotNull final String repositoryUrl)
    {
        return repositoryUrl.startsWith(SSH_SCHEME + SCHEME_DELIMITER) || (!repositoryUrl.contains(SCHEME_DELIMITER) && !(new File(repositoryUrl).exists()));
    }

    public static boolean hasScpSyntax(@NotNull String s)
    {
        int scheme = s.indexOf(SCHEME_DELIMITER);
        if (scheme!=-1)
        {
            return false; //cannot use SCP syntax when a scheme is defined
        }

        int pathDefinitelyStartsHere = s.indexOf("/");
        if (pathDefinitelyStartsHere!=-1)
        {
            s = s.substring(0, pathDefinitelyStartsHere); //don't care about anything after the first /
        }

        return s.contains(":");
    }

    public static URI getUriViaProxy(GitRepository.GitRepositoryAccessData proxyAccessData, ScpAwareUri repositoryUri) throws URISyntaxException
    {
        return new URI(repositoryUri.getScheme(),
                proxyAccessData.proxyRegistrationInfo.getProxyUserName(),
                proxyAccessData.proxyRegistrationInfo.getProxyHost(),
                proxyAccessData.proxyRegistrationInfo.getProxyPort(),
                repositoryUri.getAbsolutePath(),
                repositoryUri.getRawQuery(),
                repositoryUri.getRawFragment());
    }
}

==> atlassian-bamboo-plugin-git-2.3.5-sources.jar: com/atlassian/bamboo/plugins/git/UriUtils.java <==
package com.atlassian.bamboo.plugins.git;


import org.eclipse.jgit.transport.URIish;
import org.jetbrains.annotations.NotNull;
import org.jetbrains.annotations.Nullable;

import java.net.URI;
import java.net.URISyntaxException;

public class UriUtils
{
    static final String SSH_SCHEME = "ssh";
    static final String SCHEME_DELIMITER = "://";

    public static final String SSH_PREFIX = UriUtils.SSH_SCHEME + UriUtils.SCHEME_DELIMITER;

    private UriUtils()
    {
    }

    @Nullable
    public static String extractUsername(final String repositoryUrl) throws URISyntaxException
    {
        URIish uri = new URIish(repositoryUrl);

        final String auth = uri.getUser();
        if (auth == null)
        {
            return null;
        }
        return auth;
    }

    public static boolean requiresSshTransport(@NotNull ScpAwareUri repositoryUri)
    {
        String scheme = repositoryUri.getScheme();

        return scheme!=null && scheme.equals(SSH_SCHEME);
    }

    public static boolean requiresSshTransport(@NotNull final String repositoryUrl)
    {
        return repositoryUrl.startsWith(SSH_PREFIX) || hasScpSyntax(repositoryUrl);
    }

    public static boolean hasScpSyntax(@NotNull String url)
    {
        if (hasScheme(url))
        {
            return false; //cannot use SCP syntax when a scheme is defined
        }

        int pathDefinitelyStartsHere = url.indexOf("/");
        if (pathDefinitelyStartsHere!=-1)
        {
            url = url.substring(0, pathDefinitelyStartsHere); //don't care about anything after the first /
        }

        return url.contains(":");
    }

    private static boolean hasScheme(@NotNull String url)
    {
        int scheme = url.indexOf(SCHEME_DELIMITER);
        return scheme != -1;
    }

    public static URI getUriViaProxy(GitRepository.GitRepositoryAccessData proxyAccessData, ScpAwareUri repositoryUri) throws URISyntaxException
    {
        return new URI(repositoryUri.getScheme(),
                proxyAccessData.proxyRegistrationInfo.getProxyUserName(),
                proxyAccessData.proxyRegistrationInfo.getProxyHost(),
                proxyAccessData.proxyRegistrationInfo.getProxyPort(),
                repositoryUri.getAbsolutePath(),
                repositoryUri.getRawQuery(),
                repositoryUri.getRawFragment());
    }
}
